==> vue-option-2.21.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/option/vue';
import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import { AutoTip } from '@opentinyvue/vue-directive';
import '@opentinyvue/vue-theme/option/index.css';
import { IconCheck, IconCheckedSur, IconFinish } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Option",
  componentName: "Option",
  directives: {
    AutoTip
  },
  components: {
    IconCheck: IconCheck(),
    IconCheckedSur: IconCheckedSur(),
    IconFinish: IconFinish()
  },
  props: [].concat(props, ["value", "label", "created", "disabled", "events", "visible", "highlightClass", "required", "icon"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("li", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible && _vm.state.visible,
      expression: "visible && state.visible"
    }],
    ref: "option",
    staticClass: "tiny-option tiny-select-dropdown__item",
    class: [{
      selected: _vm.state.itemSelected,
      "is-disabled": _vm.disabled || _vm.state.groupDisabled || _vm.state.limitReached,
      hover: _vm.state.hover && !_vm.state.limitReached,
      "is-required": _vm.required
    }, _vm.highlightClass],
    attrs: {
      "data-tag": "tiny-option",
      "data-index": _vm.state.index
    },
    on: {
      "mouseenter": _vm.hoverItem,
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.selectOptionClick.apply(null, arguments);
      },
      "mousedown": function mousedown($event) {
        $event.stopPropagation();
      }
    }
  }, [_vm.state.selectMultiple ? _c("span", {
    staticClass: "tiny-option__checkbox-wrap tiny-select-dropdown__item-checkbox"
  }, [_c("icon-" + _vm.state.selectCls, {
    tag: "component",
    class: "tiny-svg-size " + _vm.state.selectCls
  })], 1) : _vm._e(), _vm.icon ? _c(_vm.icon, {
    tag: "component",
    staticClass: "tiny-option__icon"
  }) : _vm._e(), _c("div", {
    staticClass: "tiny-option-wrapper",
    class: _vm.state.selectMultiple ? "calc-width" : "full-width"
  }, [_vm._t("default", function() {
    return [_c("span", {
      directives: [{
        name: "auto-tip",
        rawName: "v-auto-tip",
        value: {
          placement: "right"
        },
        expression: "{ placement: 'right' }"
      }],
      staticClass: "tiny-option-label"
    }, [_vm._v(" " + _vm._s(_vm.state.currentLabel) + " ")])];
  })], 2)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };

==> vue-option-2.24.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/option/vue';
import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import { AutoTip } from '@opentinyvue/vue-directive';
import '@opentinyvue/vue-theme/option/index.css';
import { IconCheck, IconCheckedSur, IconFinish } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Option",
  componentName: "Option",
  directives: {
    AutoTip
  },
  components: {
    IconCheck: IconCheck(),
    IconCheckedSur: IconCheckedSur(),
    IconFinish: IconFinish()
  },
  props: [].concat(props, ["value", "label", "created", "disabled", "events", "visible", "highlightClass", "required", "icon"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("li", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible && _vm.state.visible,
      expression: "visible && state.visible"
    }],
    ref: "option",
    staticClass: "tiny-option tiny-select-dropdown__item",
    class: [{
      selected: _vm.state.itemSelected,
      "is-disabled": _vm.disabled || _vm.state.groupDisabled || _vm.state.limitReached,
      hover: _vm.state.hover && !_vm.state.limitReached,
      "is-required": _vm.required
    }, _vm.highlightClass],
    attrs: {
      "data-tag": "tiny-option",
      "data-index": _vm.state.index,
      "title": _vm.state.currentLabel || ""
    },
    on: {
      "mouseenter": _vm.hoverItem,
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.selectOptionClick.apply(null, arguments);
      },
      "mousedown": function mousedown($event) {
        $event.stopPropagation();
      }
    }
  }, [_vm.state.selectMultiple ? _c("span", {
    staticClass: "tiny-option__checkbox-wrap tiny-select-dropdown__item-checkbox"
  }, [_c("icon-" + _vm.state.selectCls, {
    tag: "component",
    class: "tiny-svg-size " + _vm.state.selectCls
  })], 1) : _vm._e(), _vm.icon ? _c(_vm.icon, {
    tag: "component",
    staticClass: "tiny-option__icon"
  }) : _vm._e(), _c("div", {
    staticClass: "tiny-option-wrapper",
    class: _vm.state.selectMultiple ? "calc-width" : "full-width"
  }, [_vm._t("default", function() {
    return [_c("span", {
      directives: [{
        name: "auto-tip",
        rawName: "v-auto-tip",
        value: {
          placement: "right"
        },
        expression: "{ placement: 'right' }"
      }],
      staticClass: "tiny-option-label"
    }, [_vm._v(" " + _vm._s(_vm.state.currentLabel) + " ")])];
  })], 2)], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
